=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2009-03-12 19:38:25 +0000
+++ drizzled/sql_base.cc	2009-03-13 21:18:49 +0000
@@ -5318,7 +5318,7 @@
       first_select_table= 0;
       tablenr= 0;
     }
-    setup_table_map(table, table_list, tablenr);
+    table->setup_table_map(table_list, tablenr);
     if (table_list->process_index_hints(table))
       return(1);
   }

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-03-11 19:04:31 +0000
+++ drizzled/sql_select.cc	2009-03-13 21:18:49 +0000
@@ -3645,7 +3645,7 @@
               keyuse->val->is_null() && keyuse->null_rejecting)
           {
             s->type= JT_CONST;
-            mark_as_null_row(table);
+            table->mark_as_null_row();
             found_const_table_map|= table->map;
 	    join->const_table_map|= table->map;
 	    set_position(join,const_count++,s,(KEYUSE*) 0);
@@ -3827,7 +3827,7 @@
 	  s->info= "Impossible ON condition";
 	  found_const_table_map|= s->table->map;
 	  s->type= JT_CONST;
-	  mark_as_null_row(s->table);		// All fields are NULL
+	  s->table->mark_as_null_row();		// All fields are NULL
 	}
       }
       if (records != HA_POS_ERROR)
@@ -8347,7 +8347,7 @@
   if (send_row)
   {
     for (TableList *table= tables; table; table= table->next_leaf)
-      mark_as_null_row(table->table);		// All fields are NULL
+      table->table->mark_as_null_row();		// All fields are NULL
     if (having && having->val_int() == 0)
       send_row=0;
   }
@@ -8379,7 +8379,7 @@
     are not re-calculated.
   */
   for (uint32_t i=join->const_tables ; i < join->tables ; i++)
-    mark_as_null_row(join->table[i]);		// All fields are NULL
+    join->table[i]->mark_as_null_row();		// All fields are NULL
 }
 
 /*****************************************************************************
@@ -11187,7 +11187,7 @@
     join_tab->not_null_compl= 0;
     /* The outer row is complemented by nulls for each inner tables */
     restore_record(join_tab->table,s->default_values);  // Make empty record
-    mark_as_null_row(join_tab->table);       // For group by without error
+    join_tab->table->mark_as_null_row();       // For group by without error
     select_cond= join_tab->select_cond;
     /* Check all attached conditions for inner table rows. */
     if (select_cond && !select_cond->val_int())
@@ -11372,7 +11372,7 @@
   if (*tab->on_expr_ref && !table->null_row)
   {
     if ((table->null_row= test((*tab->on_expr_ref)->val_int() == 0)))
-      mark_as_null_row(table);
+      table->mark_as_null_row();
   }
   if (!table->null_row)
     table->maybe_null=0;
@@ -11413,7 +11413,7 @@
     {
       if (error != HA_ERR_END_OF_FILE)
 	return table->report_error(error);
-      mark_as_null_row(tab->table);
+      tab->table->mark_as_null_row();
       empty_record(table);			// Make empty record
       return -1;
     }
@@ -11460,7 +11460,7 @@
     if (error)
     {
       table->status= STATUS_NOT_FOUND;
-      mark_as_null_row(tab->table);
+      tab->table->mark_as_null_row();
       empty_record(table);
       if (error != HA_ERR_KEY_NOT_FOUND && error != HA_ERR_END_OF_FILE)
 	return table->report_error(error);

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2009-03-11 02:39:28 +0000
+++ drizzled/table.cc	2009-03-13 21:18:49 +0000
@@ -5004,24 +5004,24 @@
 }
 
 
-void setup_table_map(Table *table, TableList *table_list, uint32_t tablenr)
+void Table::setup_table_map(TableList *table_list, uint32_t table_number)
 {
-  table->used_fields= 0;
-  table->const_table= 0;
-  table->null_row= 0;
-  table->status= STATUS_NO_RECORD;
-  table->maybe_null= table_list->outer_join;
+  used_fields= 0;
+  const_table= 0;
+  null_row= 0;
+  status= STATUS_NO_RECORD;
+  maybe_null= table_list->outer_join;
   TableList *embedding= table_list->embedding;
-  while (!table->maybe_null && embedding)
+  while (!maybe_null && embedding)
   {
-    table->maybe_null= embedding->outer_join;
+    maybe_null= embedding->outer_join;
     embedding= embedding->embedding;
   }
-  table->tablenr= tablenr;
-  table->map= (table_map) 1 << tablenr;
-  table->force_index= table_list->force_index;
-  table->covering_keys= table->s->keys_for_keyread;
-  table->merge_keys.clear_all();
+  tablenr= table_number;
+  map= (table_map) 1 << table_number;
+  force_index= table_list->force_index;
+  covering_keys= s->keys_for_keyread;
+  merge_keys.clear_all();
 }
 
 

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2009-02-19 02:29:43 +0000
+++ drizzled/table.h	2009-03-13 21:18:49 +0000
@@ -333,6 +333,22 @@
   int report_error(int error);
   int closefrm(bool free_share);
   uint32_t tmpkeyval();
+
+  /**
+    clean/setup table fields and map.
+
+    @param table        Table structure pointer (which should be setup)
+    @param table_list   TableList structure pointer (owner of Table)
+    @param tablenr     table number
+  */
+  void setup_table_map(TableList *table_list, uint32_t tablenr);
+  inline void mark_as_null_row()
+  {
+    null_row=1;
+    status|=STATUS_NULL_ROW;
+    memset(null_flags, 255, s->null_bytes);
+  }
+
 };
 
 Table *create_virtual_tmp_table(Session *session,
@@ -430,20 +446,4 @@
 } OPEN_TableList;
 
 
-inline void mark_as_null_row(Table *table)
-{
-  table->null_row=1;
-  table->status|=STATUS_NULL_ROW;
-  memset(table->null_flags, 255, table->s->null_bytes);
-}
-
-/**
-  clean/setup table fields and map.
-
-  @param table        Table structure pointer (which should be setup)
-  @param table_list   TableList structure pointer (owner of Table)
-  @param tablenr     table number
-*/
-void setup_table_map(Table *table, TableList *table_list, uint32_t tablenr);
-
 #endif /* DRIZZLED_TABLE_H */

